@@ -11,7 +11,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * DiscoveryAgentTest.cpp
  * Test fixture for the DiscoveryAgent class
@@ -68,10 +68,6 @@ class DiscoveryAgentTest: public CppUnit::TestFixture {
     void testFlakeyResponder();
     void testProxy();
 
-    void setUp() {
-      ola::InitLogging(ola::OLA_LOG_DEBUG, ola::OLA_LOG_STDERR);
-    }
-
  private:
     bool m_callback_run;
 
