@@ -11,7 +11,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * MessageDeserializerTest.cpp
  * Test fixture for the MessageDeserializer classes
@@ -76,10 +76,6 @@ class MessageDeserializerTest: public CppUnit::TestFixture {
     void testWithNestedFixedGroups();
     void testWithNestedVariableGroups();
 
-    void setUp() {
-      ola::InitLogging(ola::OLA_LOG_DEBUG, ola::OLA_LOG_STDERR);
-    }
-
  private:
     MessageDeserializer m_deserializer;
     GenericMessagePrinter m_printer;
