@@ -11,7 +11,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * MessageSerializerTest.cpp
  * Test fixture for the MessageSerializer classes
@@ -72,10 +72,6 @@ class MessageSerializerTest: public CppUnit::TestFixture {
     void testWithGroups();
     void testWithNestedGroups();
 
-    void setUp() {
-      ola::InitLogging(ola::OLA_LOG_DEBUG, ola::OLA_LOG_STDERR);
-    }
-
  private:
     const Message *BuildMessage(const Descriptor &descriptor,
                                 const vector<string> &inputs);
