@@ -11,21 +11,15 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * ResponderHelper.cpp
- * Copyright (C) 2013-2014 Simon Newton
+ * Copyright (C) 2013 Simon Newton
  */
 
 #define __STDC_LIMIT_MACROS  // for UINT8_MAX & friends
 #include <stdint.h>
 
-#ifdef WIN32
-// TODO(Peter): Do something else
-#else
-#include <net/if_arp.h>
-#endif
-
 #include <algorithm>
 #include <string>
 #include <vector>
@@ -598,7 +592,11 @@ const RDMResponse *ResponderHelper::GetRealTimeClock(
   time_t now;
   now = time(NULL);
   struct tm tm_now;
+#ifdef _WIN32
+  tm_now = *localtime(&now);  // NOLINT(runtime/threadsafe_fn)
+#else
   localtime_r(&now, &tm_now);
+#endif
 
   struct clock_s clock;
   clock.year = HostToNetwork(static_cast<uint16_t>(1900 + tm_now.tm_year));
@@ -707,7 +705,7 @@ const RDMResponse *ResponderHelper::GetInterfaceHardwareAddressType1(
   }
 
   // Only return type 1 (Ethernet)
-  if (interface.type != ARPHRD_ETHER) {
+  if (interface.type != Interface::ARP_ETHERNET_TYPE) {
     return NackWithReason(request, NR_DATA_OUT_OF_RANGE);
   }
 
