@@ -11,7 +11,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * VariableFieldSizeCalculatorTest.cpp
  * Test fixture for the VariableFieldSizeCalculator.
@@ -63,10 +63,6 @@ class VariableFieldSizeCalculatorTest: public CppUnit::TestFixture {
     void testMultipleVariableSizedFields();
     void testNestedVariableSizedGroups();
 
-    void setUp() {
-      ola::InitLogging(ola::OLA_LOG_DEBUG, ola::OLA_LOG_STDERR);
-    }
-
  private:
     ola::rdm::VariableFieldSizeCalculator m_calculator;
 };
