@@ -11,7 +11,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * TestUtils.cpp
  * Functions used for unit testing.
@@ -44,7 +44,7 @@ void ASSERT_DATA_EQUALS(unsigned int line,
                         unsigned int expected_length,
                         const uint8_t *actual,
                         unsigned int actual_length) {
-  std::stringstream str;
+  std::ostringstream str;
   str << "Line " << line;
   const string message = str.str();
   CPPUNIT_ASSERT_EQUAL_MESSAGE(message, expected_length, actual_length);
