@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  * Modified by Simon Newton (nomis52<AT>gmail.com) to use ola
  *
@@ -28,9 +28,6 @@
 #include <curses.h>
 #include <errno.h>
 #include <getopt.h>
-#ifdef HAVE_MALLOC_H
-#include <malloc.h>
-#endif
 #include <signal.h>
 #include <stdint.h>
 #include <stdio.h>
@@ -364,7 +361,7 @@ void crossfade(unsigned int new_cue) {
   /* try to find the last channel value > 0, so we don't have to
      crossfade large blocks of 0s */
   for (i = DMX_UNIVERSE_SIZE - 1; i >= 0; max = i, i--)
-    if (dmxold[i]||dmxnew[i])
+    if (dmxold[i] || dmxnew[i])
       break;
 
   {
