@@ -11,7 +11,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  *  ola-rdm.cpp
  *  The command line tool for controlling RDM devices
@@ -25,6 +25,7 @@
 #include <ola/OlaCallbackClient.h>
 #include <ola/OlaClientWrapper.h>
 #include <ola/base/SysExits.h>
+#include <ola/file/Util.h>
 #include <ola/rdm/PidStoreHelper.h>
 #include <ola/rdm/RDMAPIImplInterface.h>
 #include <ola/rdm/RDMEnums.h>
@@ -76,11 +77,9 @@ void ParseOptions(int argc, char *argv[], options *opts) {
   opts->uid = NULL;
   opts->sub_device = 0;
 
-  std::vector<string> tokens;
-  ola::StringSplit(argv[0], tokens, "/");
-
-  if (string(tokens[tokens.size() - 1]) == "ola_rdm_set")
+  if (ola::file::FilenameFromPathOrPath(argv[0]) == "ola_rdm_set") {
     opts->set_mode = true;
+  }
 
   int uid_set = 0;
   static struct option long_options[] = {
