@@ -11,11 +11,11 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * Descriptor.h
  * The Descriptor classes
- * Copyright (C) 2005-2012 Simon Newton
+ * Copyright (C) 2005 Simon Newton
  *
  * This defines all the different types of file descriptors that can be used by
  * the SelectServer. At the top level, the ReadFileDescriptor /
@@ -54,7 +54,55 @@
 namespace ola {
 namespace io {
 
-static const int INVALID_DESCRIPTOR = -1;
+// The following section of code defines the various types and helper functions
+// needed for the Descriptor infrastructure.
+// On *nix, there's the "everything is a file" philosophy, so we can just use
+// ints as handles.
+// On Windows, the situation is more complicated, so we need to treat sockets,
+// files, devices, pipes, etc. in special ways.
+#ifdef _WIN32
+// Internal use only. Semantic type of the descriptor.
+enum DescriptorType {
+  GENERIC_DESCRIPTOR = 0,  // Catch-all type without special handling
+  SOCKET_DESCRIPTOR,  // WinSock socket
+  PIPE_DESCRIPTOR  // Named Pipe handle
+};
+
+// Consider this to be an opaque type.
+struct DescriptorHandle {
+  // The actual OS handle
+  union {
+    int m_fd;
+    void* m_handle;
+  } m_handle;
+  // Type of this descriptor's handle
+  DescriptorType m_type;
+  // Handler to an event for async I/O
+  void* m_event_handle;
+  // Pointer to read result of an async I/O call
+  uint8_t* m_read_data;
+  // Pointer to size of read result data
+  uint32_t* m_read_data_size;
+
+  DescriptorHandle()
+      : m_type(GENERIC_DESCRIPTOR),
+      m_event_handle(0),
+      m_read_data(NULL),
+      m_read_data_size(NULL) {
+    m_handle.m_fd = -1;
+  }
+};
+
+static DescriptorHandle INVALID_DESCRIPTOR;
+static const size_t READ_DATA_BUFFER_SIZE = 1024;
+bool operator!=(const DescriptorHandle &lhs, const DescriptorHandle &rhs);
+bool operator==(const DescriptorHandle &lhs, const DescriptorHandle &rhs);
+bool operator<(const DescriptorHandle &lhs, const DescriptorHandle &rhs);
+std::ostream& operator<<(std::ostream &stream, const DescriptorHandle &data);
+#else
+typedef int DescriptorHandle;
+static DescriptorHandle INVALID_DESCRIPTOR = -1;
+#endif
 
 /*
  * A FileDescriptor which can be read from.
@@ -64,7 +112,7 @@ class ReadFileDescriptor {
   virtual ~ReadFileDescriptor() {}
 
   // Returns the read descriptor for this socket
-  virtual int ReadDescriptor() const = 0;
+  virtual DescriptorHandle ReadDescriptor() const = 0;
 
   // True if the read descriptor is valid
   bool ValidReadDescriptor() const {
@@ -82,7 +130,7 @@ class ReadFileDescriptor {
 class WriteFileDescriptor {
  public:
   virtual ~WriteFileDescriptor() {}
-  virtual int WriteDescriptor() const = 0;
+  virtual DescriptorHandle WriteDescriptor() const = 0;
 
   // True if the write descriptor is valid
   bool ValidWriteDescriptor() const {
@@ -136,21 +184,19 @@ class BidirectionalFileDescriptor: public ReadFileDescriptor,
 /*
  * An UnmanagedFileDescriptor allows file descriptors from other software to
  * use the SelectServer. This class doesn't define any read/write methods, it
- * simply allows a third-party sd to be registered with a callback.
+ * simply allows a third-party fd to be registered with a callback.
  */
 class UnmanagedFileDescriptor: public BidirectionalFileDescriptor {
  public :
-  explicit UnmanagedFileDescriptor(int fd)
-      : BidirectionalFileDescriptor(),
-        m_fd(fd) {}
+  explicit UnmanagedFileDescriptor(int fd);
   ~UnmanagedFileDescriptor() {}
-  int ReadDescriptor() const { return m_fd; }
-  int WriteDescriptor() const { return m_fd; }
+  DescriptorHandle ReadDescriptor() const { return m_handle; }
+  DescriptorHandle WriteDescriptor() const { return m_handle; }
   // Closing is left to something else
   bool Close() { return true; }
 
  private:
-  int m_fd;
+  DescriptorHandle m_handle;
   UnmanagedFileDescriptor(const UnmanagedFileDescriptor &other);
   UnmanagedFileDescriptor& operator=(const UnmanagedFileDescriptor &other);
 };
@@ -217,11 +263,11 @@ class ConnectedDescriptor: public BidirectionalFileDescriptor {
     return on_close;
   }
 
-  static bool SetNonBlocking(int fd);
+  static bool SetNonBlocking(DescriptorHandle fd);
 
  protected:
   virtual bool IsSocket() const = 0;
-  bool SetNoSigPipe(int fd);
+  bool SetNoSigPipe(DescriptorHandle fd);
 
   ConnectedDescriptor(const ConnectedDescriptor &other);
   ConnectedDescriptor& operator=(const ConnectedDescriptor &other);
@@ -238,13 +284,17 @@ class ConnectedDescriptor: public BidirectionalFileDescriptor {
 class LoopbackDescriptor: public ConnectedDescriptor {
  public:
   LoopbackDescriptor() {
-    m_fd_pair[0] = INVALID_DESCRIPTOR;
-    m_fd_pair[1] = INVALID_DESCRIPTOR;
+    m_handle_pair[0] = INVALID_DESCRIPTOR;
+    m_handle_pair[1] = INVALID_DESCRIPTOR;
+#ifdef _WIN32
+    memset(m_read_data, 0, READ_DATA_BUFFER_SIZE);
+    m_read_data_size = 0;
+#endif
   }
   ~LoopbackDescriptor() { Close(); }
   bool Init();
-  int ReadDescriptor() const { return m_fd_pair[0]; }
-  int WriteDescriptor() const { return m_fd_pair[1]; }
+  DescriptorHandle ReadDescriptor() const { return m_handle_pair[0]; }
+  DescriptorHandle WriteDescriptor() const { return m_handle_pair[1]; }
   bool Close();
   bool CloseClient();
 
@@ -252,9 +302,13 @@ class LoopbackDescriptor: public ConnectedDescriptor {
   bool IsSocket() const { return false; }
 
  private:
-  int m_fd_pair[2];
+  DescriptorHandle m_handle_pair[2];
   LoopbackDescriptor(const LoopbackDescriptor &other);
   LoopbackDescriptor& operator=(const LoopbackDescriptor &other);
+#ifdef _WIN32
+  uint8_t m_read_data[READ_DATA_BUFFER_SIZE];
+  uint32_t m_read_data_size;
+#endif
 };
 
 
@@ -268,13 +322,17 @@ class PipeDescriptor: public ConnectedDescriptor {
     m_other_end(NULL) {
     m_in_pair[0] = m_in_pair[1] = INVALID_DESCRIPTOR;
     m_out_pair[0] = m_out_pair[1] = INVALID_DESCRIPTOR;
+#ifdef _WIN32
+    memset(m_read_data, 0, READ_DATA_BUFFER_SIZE);
+    m_read_data_size = 0;
+#endif
   }
   ~PipeDescriptor() { Close(); }
 
   bool Init();
   PipeDescriptor *OppositeEnd();
-  int ReadDescriptor() const { return m_in_pair[0]; }
-  int WriteDescriptor() const { return m_out_pair[1]; }
+  DescriptorHandle ReadDescriptor() const { return m_in_pair[0]; }
+  DescriptorHandle WriteDescriptor() const { return m_out_pair[1]; }
   bool Close();
   bool CloseClient();
 
@@ -282,21 +340,30 @@ class PipeDescriptor: public ConnectedDescriptor {
   bool IsSocket() const { return false; }
 
  private:
-  int m_in_pair[2];
-  int m_out_pair[2];
+  DescriptorHandle m_in_pair[2];
+  DescriptorHandle m_out_pair[2];
   PipeDescriptor *m_other_end;
-  PipeDescriptor(int in_pair[2], int out_pair[2], PipeDescriptor *other_end) {
+  PipeDescriptor(DescriptorHandle in_pair[2],
+                 DescriptorHandle out_pair[2],
+                 PipeDescriptor *other_end) {
     m_in_pair[0] = in_pair[0];
     m_in_pair[1] = in_pair[1];
     m_out_pair[0] = out_pair[0];
     m_out_pair[1] = out_pair[1];
     m_other_end = other_end;
+#ifdef _WIN32
+    m_in_pair[0].m_read_data = m_read_data;
+    m_in_pair[0].m_read_data_size = &m_read_data_size;
+#endif
   }
   PipeDescriptor(const PipeDescriptor &other);
   PipeDescriptor& operator=(const PipeDescriptor &other);
+#ifdef _WIN32
+  uint8_t m_read_data[READ_DATA_BUFFER_SIZE];
+  uint32_t m_read_data_size;
+#endif
 };
 
-
 /*
  * A unix domain socket pair.
  */
@@ -304,14 +371,14 @@ class UnixSocket: public ConnectedDescriptor {
  public:
   UnixSocket():
     m_other_end(NULL) {
-    m_fd = INVALID_DESCRIPTOR;
+    m_handle = INVALID_DESCRIPTOR;
   }
   ~UnixSocket() { Close(); }
 
   bool Init();
   UnixSocket *OppositeEnd();
-  int ReadDescriptor() const { return m_fd; }
-  int WriteDescriptor() const { return m_fd; }
+  DescriptorHandle ReadDescriptor() const { return m_handle; }
+  DescriptorHandle WriteDescriptor() const { return m_handle; }
   bool Close();
   bool CloseClient();
 
@@ -319,34 +386,37 @@ class UnixSocket: public ConnectedDescriptor {
   bool IsSocket() const { return true; }
 
  private:
-  int m_fd;
+  DescriptorHandle m_handle;
   UnixSocket *m_other_end;
   UnixSocket(int socket, UnixSocket *other_end) {
-    m_fd = socket;
+#ifdef _WIN32
+    m_handle.m_handle.m_fd = socket;
+#else
+    m_handle = socket;
+#endif
     m_other_end = other_end;
   }
   UnixSocket(const UnixSocket &other);
   UnixSocket& operator=(const UnixSocket &other);
 };
 
-
 /*
  * A descriptor which represents a connection to a device
  */
 class DeviceDescriptor: public ConnectedDescriptor {
  public:
-  explicit DeviceDescriptor(int fd): m_fd(fd) {}
+  explicit DeviceDescriptor(int fd);
   ~DeviceDescriptor() { Close(); }
 
-  int ReadDescriptor() const { return m_fd; }
-  int WriteDescriptor() const { return m_fd; }
+  DescriptorHandle ReadDescriptor() const { return m_handle; }
+  DescriptorHandle WriteDescriptor() const { return m_handle; }
   bool Close();
 
  protected:
   bool IsSocket() const { return false; }
 
  private:
-  int m_fd;
+  DescriptorHandle m_handle;
   DeviceDescriptor(const DeviceDescriptor &other);
   DeviceDescriptor& operator=(const DeviceDescriptor &other);
 };
