@@ -11,7 +11,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * StdinHandler.h
  * Enables reading input from stdin one character at a time. Useful if you want
@@ -22,7 +22,9 @@
 #ifndef INCLUDE_OLA_IO_STDINHANDLER_H_
 #define INCLUDE_OLA_IO_STDINHANDLER_H_
 
+#ifndef _WIN32
 #include <termios.h>
+#endif
 #include <ola/Callback.h>
 #include <ola/io/Descriptor.h>
 #include <ola/io/SelectServerInterface.h>
@@ -41,7 +43,9 @@ class StdinHandler {
 
  private:
   UnmanagedFileDescriptor m_stdin_descriptor;
+#ifndef _WIN32
   termios m_old_tc;
+#endif
   SelectServerInterface *m_ss;
   std::auto_ptr<InputCallback> m_callback;
 
