@@ -11,7 +11,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * SocketAddress.h
  * Represents a sockaddr structure.
@@ -31,7 +31,12 @@
 
 #include <ola/network/IPV4Address.h>
 #include <stdint.h>
+#ifdef _WIN32
+#define VC_EXTRALEAN
+#include <Winsock2.h>
+#else
 #include <sys/socket.h>
+#endif
 #include <sstream>
 #include <string>
 
