@@ -11,7 +11,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * OlaCallbackClient.cpp
  * Implementation of OlaCallbackClient
@@ -467,7 +467,9 @@ void OlaCallbackClient::HandleDiscovery(
 void OlaCallbackClient::HandleSetCallback(
     ola::SingleUseCallback1<void, const string&> *callback,
     const Result &result) {
-  callback->Run(result.Error());
+  if (callback) {
+    callback->Run(result.Error());
+  }
 }
 
 void OlaCallbackClient::HandleRepeatableSetCallback(
