@@ -11,7 +11,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * OlaClient.cpp
  * Implementation of OlaClient
@@ -60,6 +60,10 @@ void OlaClient::SetDMXCallback(RepeatableDMXCallback *callback) {
   m_core->SetDMXCallback(callback);
 }
 
+void OlaClient::ReloadPlugins(SetCallback *callback) {
+  m_core->ReloadPlugins(callback);
+}
+
 void OlaClient::FetchPluginList(PluginListCallback *callback) {
   m_core->FetchPluginList(callback);
 }
