@@ -11,7 +11,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  * OlaServerServiceImpl.cpp
  * Implementation of the OlaServerService interface. This is the class that
@@ -387,6 +387,19 @@ void OlaServerServiceImpl::GetPlugins(
   }
 }
 
+void OlaServerServiceImpl::ReloadPlugins(
+    RpcController*,
+    const ::ola::proto::PluginReloadRequest*,
+    ola::proto::Ack*,
+    ola::rpc::RpcService::CompletionCallback* done) {
+  ClosureRunner runner(done);
+  if (m_reload_plugins_callback.get()) {
+    m_reload_plugins_callback->Run();
+  } else {
+    OLA_WARN << "No plugin reload callback provided!";
+  }
+}
+
 
 /*
  * Return the description for a plugin.
