@@ -11,11 +11,11 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  * PluginManagerTest.cpp
  * Test fixture for the PluginManager classes
- * Copyright (C) 2005-2009 Simon Newton
+ * Copyright (C) 2005 Simon Newton
  */
 
 #include <cppunit/extensions/HelperMacros.h>
@@ -57,7 +57,7 @@ class PluginManagerTest: public CppUnit::TestFixture {
  private:
     void VerifyPluginCounts(PluginManager *manager, size_t loaded_plugins,
                             size_t active_plugins, unsigned int line) {
-      std::stringstream str;
+      std::ostringstream str;
       str << "Line " << line;
       vector<AbstractPlugin*> plugins;
       manager->Plugins(&plugins);
