@@ -11,11 +11,11 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  * UniverseTest.cpp
  * Test fixture for the Universe and UniverseStore classes
- * Copyright (C) 2005-2008 Simon Newton
+ * Copyright (C) 2005 Simon Newton
  */
 
 #include <cppunit/extensions/HelperMacros.h>
@@ -819,7 +819,7 @@ void UniverseTest::ConfirmRDM(int line,
                               rdm_response_code response_code,
                               const RDMResponse *response,
                               const vector<string>&) {
-  std::stringstream str;
+  std::ostringstream str;
   str << "Line " << line;
   OLA_ASSERT_EQ_MSG(expected_response_code,
                     response_code,
