@@ -11,7 +11,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  * ArtNetPort.cpp
  * The ArtNet plugin for ola
@@ -88,7 +88,7 @@ string ArtNetInputPort::Description() const {
   if (!GetUniverse())
     return "";
 
-  std::stringstream str;
+  std::ostringstream str;
   str << "ArtNet Universe " <<
     static_cast<int>(m_node->NetAddress()) << ":" <<
     static_cast<int>(m_node->SubnetAddress()) << ":" <<
@@ -195,7 +195,7 @@ string ArtNetOutputPort::Description() const {
   if (!GetUniverse())
     return "";
 
-  std::stringstream str;
+  std::ostringstream str;
   str << "ArtNet Universe " <<
     static_cast<int>(m_node->NetAddress()) << ":" <<
     static_cast<int>(m_node->SubnetAddress()) << ":" <<
