@@ -11,11 +11,11 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  * EspNetPort.cpp
  * The EspNet plugin for ola
- * Copyright (C) 2005-2009 Simon Newton
+ * Copyright (C) 2005 Simon Newton
  */
 
 #include <algorithm>
@@ -34,7 +34,7 @@ namespace espnet {
 using std::string;
 
 string EspNetPortHelper::Description(Universe *universe) const {
-  std::stringstream str;
+  std::ostringstream str;
   if (universe)
     str << "EspNet universe " << (unsigned int) EspNetUniverseId(universe);
   return str.str();
