@@ -11,11 +11,11 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  * KarateDevice.cpp
  * The KarateLight device
- * Copyright (C) 2005-2008 Simon Newton
+ * Copyright (C) 2005 Simon Newton
  */
 
 #include <string>
@@ -43,7 +43,7 @@ KarateDevice::KarateDevice(AbstractPlugin *owner,
                            unsigned int device_id)
     : Device(owner, name),
       m_path(path) {
-  std::stringstream str;
+  std::ostringstream str;
   str << device_id;
   m_device_id = str.str();
 }
