@@ -11,7 +11,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  * OSCNode.cpp
  * A self contained object for sending and receiving OSC messages.
@@ -593,7 +593,7 @@ bool OSCNode::SendIndividualMessages(const DmxBuffer &dmx_data,
 
     vector<SlotMessage>::const_iterator message_iter = messages.begin();
     for (; message_iter != messages.end(); ++message_iter) {
-      std::stringstream path;
+      std::ostringstream path;
       path << (*target_iter)->osc_address << "/" << message_iter->slot + 1;
 
       int ret = lo_send_message_from((*target_iter)->liblo_address,
