@@ -11,12 +11,12 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  *
  * SandNetPort.cpp
  * The SandNet plugin for ola
- * Copyright (C) 2005-2009 Simon Newton
+ * Copyright (C) 2005 Simon Newton
  */
 
 #include <sstream>
@@ -36,7 +36,7 @@ string PathportPortHelper::Description(const Universe *universe) const {
   if (!universe)
     return "";
 
-  std::stringstream str;
+  std::ostringstream str;
   str << "Pathport xDMX " << DMX_UNIVERSE_SIZE * universe->UniverseId() <<
     " - " << DMX_UNIVERSE_SIZE * (1 + universe->UniverseId()) - 1;
   return str.str();
