@@ -11,11 +11,11 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  * ShowNetPort.cpp
  * The ShowNet plugin for ola
- * Copyright (C) 2005-2009 Simon Newton
+ * Copyright (C) 2005 Simon Newton
  */
 #include <sstream>
 #include <string>
@@ -33,7 +33,7 @@ namespace shownet {
 using std::string;
 
 string ShowNetInputPort::Description() const {
-  std::stringstream str;
+  std::ostringstream str;
   str << "ShowNet " << PortId() * DMX_UNIVERSE_SIZE + 1 << "-" <<
     (PortId() + 1) * DMX_UNIVERSE_SIZE;
   return str.str();
@@ -75,7 +75,7 @@ void ShowNetInputPort::PostSetUniverse(Universe *old_universe,
 
 
 string ShowNetOutputPort::Description() const {
-  std::stringstream str;
+  std::ostringstream str;
   str << "ShowNet " << PortId() * DMX_UNIVERSE_SIZE + 1 << "-" <<
     (PortId() + 1) * DMX_UNIVERSE_SIZE;
   return str.str();
